==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkDataRepresentation.java <==
// java wrapper for vtkDataRepresentation object
//

package vtk;
import vtk.*;

public class vtkDataRepresentation extends vtkPassInputTypeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInputConnection_2(int id0,int id1);
  public vtkAlgorithmOutput GetInputConnection(int id0,int id1) {
    long temp = GetInputConnection_2(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetAnnotationLink_3();
  public vtkAnnotationLink GetAnnotationLink() {
    long temp = GetAnnotationLink_3();

    if (temp == 0) return null;
    return (vtkAnnotationLink)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetAnnotationLink_4(vtkAnnotationLink id0);
  public void SetAnnotationLink(vtkAnnotationLink id0)
    { SetAnnotationLink_4(id0); }

  private native void ApplyViewTheme_5(vtkViewTheme id0);
  public void ApplyViewTheme(vtkViewTheme id0)
    { ApplyViewTheme_5(id0); }

  private native void Select_6(vtkView id0,vtkSelection id1);
  public void Select(vtkView id0,vtkSelection id1)
    { Select_6(id0,id1); }

  private native void Select_7(vtkView id0,vtkSelection id1,boolean id2);
  public void Select(vtkView id0,vtkSelection id1,boolean id2)
    { Select_7(id0,id1,id2); }

  private native void Annotate_8(vtkView id0,vtkAnnotationLayers id1);
  public void Annotate(vtkView id0,vtkAnnotationLayers id1)
    { Annotate_8(id0,id1); }

  private native void Annotate_9(vtkView id0,vtkAnnotationLayers id1,boolean id2);
  public void Annotate(vtkView id0,vtkAnnotationLayers id1,boolean id2)
    { Annotate_9(id0,id1,id2); }

  private native void SetSelectable_10(boolean id0);
  public void SetSelectable(boolean id0)
    { SetSelectable_10(id0); }

  private native boolean GetSelectable_11();
  public boolean GetSelectable()
    { return GetSelectable_11(); }

  private native void SelectableOn_12();
  public void SelectableOn()
    { SelectableOn_12(); }

  private native void SelectableOff_13();
  public void SelectableOff()
    { SelectableOff_13(); }

  private native void UpdateSelection_14(vtkSelection id0);
  public void UpdateSelection(vtkSelection id0)
    { UpdateSelection_14(id0); }

  private native void UpdateSelection_15(vtkSelection id0,boolean id1);
  public void UpdateSelection(vtkSelection id0,boolean id1)
    { UpdateSelection_15(id0,id1); }

  private native void UpdateAnnotations_16(vtkAnnotationLayers id0);
  public void UpdateAnnotations(vtkAnnotationLayers id0)
    { UpdateAnnotations_16(id0); }

  private native void UpdateAnnotations_17(vtkAnnotationLayers id0,boolean id1);
  public void UpdateAnnotations(vtkAnnotationLayers id0,boolean id1)
    { UpdateAnnotations_17(id0,id1); }

  private native long GetInternalAnnotationOutputPort_18();
  public vtkAlgorithmOutput GetInternalAnnotationOutputPort() {
    long temp = GetInternalAnnotationOutputPort_18();

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInternalAnnotationOutputPort_19(int id0);
  public vtkAlgorithmOutput GetInternalAnnotationOutputPort(int id0) {
    long temp = GetInternalAnnotationOutputPort_19(id0);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInternalAnnotationOutputPort_20(int id0,int id1);
  public vtkAlgorithmOutput GetInternalAnnotationOutputPort(int id0,int id1) {
    long temp = GetInternalAnnotationOutputPort_20(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInternalSelectionOutputPort_21();
  public vtkAlgorithmOutput GetInternalSelectionOutputPort() {
    long temp = GetInternalSelectionOutputPort_21();

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInternalSelectionOutputPort_22(int id0);
  public vtkAlgorithmOutput GetInternalSelectionOutputPort(int id0) {
    long temp = GetInternalSelectionOutputPort_22(id0);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInternalSelectionOutputPort_23(int id0,int id1);
  public vtkAlgorithmOutput GetInternalSelectionOutputPort(int id0,int id1) {
    long temp = GetInternalSelectionOutputPort_23(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInternalOutputPort_24();
  public vtkAlgorithmOutput GetInternalOutputPort() {
    long temp = GetInternalOutputPort_24();

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInternalOutputPort_25(int id0);
  public vtkAlgorithmOutput GetInternalOutputPort(int id0) {
    long temp = GetInternalOutputPort_25(id0);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInternalOutputPort_26(int id0,int id1);
  public vtkAlgorithmOutput GetInternalOutputPort(int id0,int id1) {
    long temp = GetInternalOutputPort_26(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSelectionType_27(int id0);
  public void SetSelectionType(int id0)
    { SetSelectionType_27(id0); }

  private native int GetSelectionType_28();
  public int GetSelectionType()
    { return GetSelectionType_28(); }

  private native void SetSelectionArrayNames_29(vtkStringArray id0);
  public void SetSelectionArrayNames(vtkStringArray id0)
    { SetSelectionArrayNames_29(id0); }

  private native long GetSelectionArrayNames_30();
  public vtkStringArray GetSelectionArrayNames() {
    long temp = GetSelectionArrayNames_30();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSelectionArrayName_31(String id0);
  public void SetSelectionArrayName(String id0)
    { SetSelectionArrayName_31(id0); }

  private native String GetSelectionArrayName_32();
  public String GetSelectionArrayName()
    { return GetSelectionArrayName_32(); }

  private native long ConvertSelection_33(vtkView id0,vtkSelection id1);
  public vtkSelection ConvertSelection(vtkView id0,vtkSelection id1) {
    long temp = ConvertSelection_33(id0,id1);

    if (temp == 0) return null;
    return (vtkSelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkDataRepresentation() { super(); }

  public vtkDataRepresentation(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-2-aarch64.pkg.tar.xz: vtk/vtkDataRepresentation.java <==
// java wrapper for vtkDataRepresentation object
//

package vtk;
import vtk.*;

public class vtkDataRepresentation extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInputConnection_2(int id0,int id1);
  public vtkAlgorithmOutput GetInputConnection(int id0,int id1) {
    long temp = GetInputConnection_2(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetAnnotationLink_3();
  public vtkAnnotationLink GetAnnotationLink() {
    long temp = GetAnnotationLink_3();

    if (temp == 0) return null;
    return (vtkAnnotationLink)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAnnotationLink_4(vtkAnnotationLink id0);
  public void SetAnnotationLink(vtkAnnotationLink id0)
    { SetAnnotationLink_4(id0); }

  private native void ApplyViewTheme_5(vtkViewTheme id0);
  public void ApplyViewTheme(vtkViewTheme id0)
    { ApplyViewTheme_5(id0); }

  private native void Select_6(vtkView id0,vtkSelection id1);
  public void Select(vtkView id0,vtkSelection id1)
    { Select_6(id0,id1); }

  private native void Select_7(vtkView id0,vtkSelection id1,boolean id2);
  public void Select(vtkView id0,vtkSelection id1,boolean id2)
    { Select_7(id0,id1,id2); }

  private native void Annotate_8(vtkView id0,vtkAnnotationLayers id1);
  public void Annotate(vtkView id0,vtkAnnotationLayers id1)
    { Annotate_8(id0,id1); }

  private native void Annotate_9(vtkView id0,vtkAnnotationLayers id1,boolean id2);
  public void Annotate(vtkView id0,vtkAnnotationLayers id1,boolean id2)
    { Annotate_9(id0,id1,id2); }

  private native void SetSelectable_10(boolean id0);
  public void SetSelectable(boolean id0)
    { SetSelectable_10(id0); }

  private native boolean GetSelectable_11();
  public boolean GetSelectable()
    { return GetSelectable_11(); }

  private native void SelectableOn_12();
  public void SelectableOn()
    { SelectableOn_12(); }

  private native void SelectableOff_13();
  public void SelectableOff()
    { SelectableOff_13(); }

  private native void UpdateSelection_14(vtkSelection id0);
  public void UpdateSelection(vtkSelection id0)
    { UpdateSelection_14(id0); }

  private native void UpdateSelection_15(vtkSelection id0,boolean id1);
  public void UpdateSelection(vtkSelection id0,boolean id1)
    { UpdateSelection_15(id0,id1); }

  private native void UpdateAnnotations_16(vtkAnnotationLayers id0);
  public void UpdateAnnotations(vtkAnnotationLayers id0)
    { UpdateAnnotations_16(id0); }

  private native void UpdateAnnotations_17(vtkAnnotationLayers id0,boolean id1);
  public void UpdateAnnotations(vtkAnnotationLayers id0,boolean id1)
    { UpdateAnnotations_17(id0,id1); }

  private native long GetInternalAnnotationOutputPort_18();
  public vtkAlgorithmOutput GetInternalAnnotationOutputPort() {
    long temp = GetInternalAnnotationOutputPort_18();

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInternalAnnotationOutputPort_19(int id0);
  public vtkAlgorithmOutput GetInternalAnnotationOutputPort(int id0) {
    long temp = GetInternalAnnotationOutputPort_19(id0);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInternalAnnotationOutputPort_20(int id0,int id1);
  public vtkAlgorithmOutput GetInternalAnnotationOutputPort(int id0,int id1) {
    long temp = GetInternalAnnotationOutputPort_20(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInternalSelectionOutputPort_21();
  public vtkAlgorithmOutput GetInternalSelectionOutputPort() {
    long temp = GetInternalSelectionOutputPort_21();

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInternalSelectionOutputPort_22(int id0);
  public vtkAlgorithmOutput GetInternalSelectionOutputPort(int id0) {
    long temp = GetInternalSelectionOutputPort_22(id0);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInternalSelectionOutputPort_23(int id0,int id1);
  public vtkAlgorithmOutput GetInternalSelectionOutputPort(int id0,int id1) {
    long temp = GetInternalSelectionOutputPort_23(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInternalOutputPort_24();
  public vtkAlgorithmOutput GetInternalOutputPort() {
    long temp = GetInternalOutputPort_24();

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInternalOutputPort_25(int id0);
  public vtkAlgorithmOutput GetInternalOutputPort(int id0) {
    long temp = GetInternalOutputPort_25(id0);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInternalOutputPort_26(int id0,int id1);
  public vtkAlgorithmOutput GetInternalOutputPort(int id0,int id1) {
    long temp = GetInternalOutputPort_26(id0,id1);

    if (temp == 0) return null;
    return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionType_27(int id0);
  public void SetSelectionType(int id0)
    { SetSelectionType_27(id0); }

  private native int GetSelectionType_28();
  public int GetSelectionType()
    { return GetSelectionType_28(); }

  private native void SetSelectionArrayNames_29(vtkStringArray id0);
  public void SetSelectionArrayNames(vtkStringArray id0)
    { SetSelectionArrayNames_29(id0); }

  private native long GetSelectionArrayNames_30();
  public vtkStringArray GetSelectionArrayNames() {
    long temp = GetSelectionArrayNames_30();

    if (temp == 0) return null;
    return (vtkStringArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionArrayName_31(String id0);
  public void SetSelectionArrayName(String id0)
    { SetSelectionArrayName_31(id0); }

  private native String GetSelectionArrayName_32();
  public String GetSelectionArrayName()
    { return GetSelectionArrayName_32(); }

  private native long ConvertSelection_33(vtkView id0,vtkSelection id1);
  public vtkSelection ConvertSelection(vtkView id0,vtkSelection id1) {
    long temp = ConvertSelection_33(id0,id1);

    if (temp == 0) return null;
    return (vtkSelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkDataRepresentation() { super(); }

  public vtkDataRepresentation(long id) { super(id); }
  public native long   VTKInit();

}
